###########################################################################
#
# Collage.pm --
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 1999 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

package Collage;

use BasClas;
use sorttools;

sub BEGIN {
    @ISA = ('BasClas');
}

my $arguments = 
    [ { 'name' => "buttonname",
  	'desc' => "{BasClas.buttonname}",
	'type' => "string",
	'deft' => "Collage",
	'reqd' => "no" }];

my $options = { 'name'     => "Collage",
		'desc'     => "{Collage.desc}",
		'inherits' => "Yes",
		'args'     => $arguments };


sub new {
    my $class = shift (@_);
    my $self = new BasClas($class, @_);

    my $option_list = $self->{'option_list'};
    push( @{$option_list}, $options );

    if ($self->{'info_only'}) {
	# created from classinfo.pl - don't need to parse the arguments
	return bless $self, $class;
    }   

    my ($title, $list);

    if (!parsargv::parse(\@_, 
			 q^buttonname/.*/^, \$title,
			 "allow_extra_options")) {
	
	print STDERR "\nIncorrect options passed to $class, check your collect.cfg file\n";
	$self->print_txt_usage("");  # Use default resource bundle
	die "\n";
    }

    if (!$title) {
	$title = 'Collage';
    }

    $self->{'collection'} = $ENV{'GSDLCOLLECTION'};
    $self->{'list'} = $list;
    $self->{'title'} = $title;
    
    return bless $self, $class;
}

sub init {
    my $self = shift (@_);

    $self->{'list'} = [];
}

sub classify {
   
    my $self = shift (@_);
    my ($doc_obj) = @_;

    my $doc_OID = $doc_obj->get_OID();
    push (@{$self->{'list'}}, $doc_OID);

    foreach $assoc_file (@{$doc_obj->get_assoc_files()}) {
	push (@{$self->{'imagelist'}}, $assoc_file->[1]);
    }

}

sub get_classify_info {
    my $self = shift (@_);
    
    my @imagelist = ();
    @imagelist = @{$self->{'imagelist'}};

    my @list = ();
    @list = @{$self->{'list'}};

    print STDOUT ("$self->{'title'}\n");

    my $classifyinfo = $self->get_entry ($self->{'title'}, "Collage", "Invisible");

    my %collage = ();
    
    foreach $oid (@list) {
	push (@{$collage->{'contains'}}, {'OID'=>$oid});
    }
   
    push (@{$classifyinfo->{'contains'}}, $collage);

    return $classifyinfo;
}


sub get_entry {
    my $self = shift (@_);
    my ($title, $childtype, $thistype) = @_;
    
    
    # organise into classification structure
    my %classifyinfo = ('thistype'=>$thistype,
			'childtype'=>$childtype,
			'Title'=>$title,
			'contains'=>[]);
    
    return \%classifyinfo;
}

1;
